@@ -3,6 +3,7 @@ Built-in :class:`~tango.step.Step` implementations that are not tied to any part
 integration.
 """
 
-__all__ = ["DatasetRemixStep"]
+__all__ = ["DatasetRemixStep", "PrintStep"]
 
 from .dataset_remix import DatasetRemixStep
+from .print import PrintStep
